public class Cinema {

    private String nome;
    private int filmMax;
    private Film[] film;

    public Cinema(String nome, int filmMax) {
        this.nome = nome;
        this.filmMax = filmMax;
        this.film = new Film[filmMax];
        for (int i = 0; i < film.length; i++) {
            film[i] = null;
        }
    }

    /**
     * Aggiunge un film all'array di film.
     *
     * Questo metodo cerca un posto libero nell'array di film e aggiunge il film
     * se non è già presente.
     *
     * @param f il film da aggiungere
     */
    public void aggiungiFilm(Film f) {
        for (int i = 0; i < film.length; i++) {
            if (film[i] == null) {
                film[i] = f;
                break;
            } else if (film[i].equals(f)) {
                System.out.println("Film già presente");
                break;
            }
        }
    }

    /**
     * Prenota il numero specificato di posti per un determinato film.
     *
     * Questo metodo cerca dentro l'array di film per trovare il film specificato.
     * Se il film viene trovato, tenta di prenotare il numero specificato di posti utilizzando
     * il metodo vendiBiglietti della classe Film. Il metodo restituisce true se
     * la prenotazione ha successo, altrimenti restituisce false.
     *
     * @param Posti il numero di posti da prenotare
     * @param film il film per cui prenotare i posti
     * @return `true` se i posti sono stati prenotati con successo, `false` altrimenti
     */
    public boolean prenotaPosti(int Posti, Film film) {
        for (Film f : this.film) {
            if (f != null && f.equals(film)) {
                return f.vendiBiglietti(Posti);
            }
        }
        return false;
    }

    /**
     * Restituisce una copia del film con la durata maggiore.
     *
     * Questo metodo itera attraverso l'array di film per trovare il film con la durata maggiore.
     * Se il film viene trovato, restituisce una nuova istanza del film con gli stessi attributi.
     *
     * @return una copia del film con la durata maggiore
     */
    public Film filmPiùLungo() {
        Film filmPiuLungo = this.film[0];
        for (Film f : this.film) {
            if (f != null && f.getDurata() > filmPiuLungo.getDurata()) {
                filmPiuLungo = f;
            }
        }
        return new Film(filmPiuLungo.getTitolo(), filmPiuLungo.getDurata(), filmPiuLungo.getSala(), filmPiuLungo.getPostiDisponibili());
    }

    /**
     * Calcola e stampa la percentuale di posti occupati per un determinato film.
     *
     * Questo metodo cerca il film specificato nell'array di film e calcola la percentuale
     * di posti occupati rispetto al totale dei posti disponibili.
     *
     * @param film il film per cui calcolare la percentuale di posti occupati
     */
    public void percentualePostiOccupati(Film film) {
        for (Film f : this.film) {
            if (f != null && f.equals(film)) {
                int postiTotali = f.getPostiTotali();
                int postiDisponibili = f.getPostiDisponibili();
                int postiOccupati = postiTotali - postiDisponibili;
                double percentuale = (double) postiOccupati / postiTotali * 100;
                System.out.println("Percentuale posti occupati: " + percentuale + "%");
                return;
            }
        }
        System.out.println("Film non trovato");
    }

    public void rimuoviFilm(Film film) {
        for (int i = 0; i < this.film.length; i++) {
            if (this.film[i] != null && this.film[i].equals(film)) {
                this.film[i] = null;
                return;
            }
        }
        System.out.println("Film non trovato");
    }

    public void stampaProgrammazione() {
        for (Film f : this.film) {
            if (f != null) {
                System.out.println("Titolo: " + f.getTitolo() + " Durata: " + f.getDurata() + " Sala: " + f.getSala() + " Posti: " + f.getPostiDisponibili());
            }
        }
    }
}